@@ -22,10 +22,10 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 #
-# $Id: ajp_base.py 2188 2006-12-05 22:11:45Z asaddi $
+# $Id$
 
 __author__ = 'Allan Saddi <allan@saddi.com>'
-__version__ = '$Revision: 2188 $'
+__version__ = '$Revision$'
 
 import sys
 import socket
@@ -924,8 +924,15 @@ class BaseAJPServer(object):
         environ['PATH_INFO'] = value[len(scriptName):]
         environ['SCRIPT_NAME'] = scriptName
 
-        if not environ.has_key('QUERY_STRING'):
-            environ['QUERY_STRING'] = ''
+        reqUri = None
+        if environ.has_key('REQUEST_URI'):
+            reqUri = environ['REQUEST_URI'].split('?', 1)
+
+        if not environ.has_key('QUERY_STRING') or not environ['QUERY_STRING']:
+            if reqUri is not None and len(reqUri) > 1:
+                environ['QUERY_STRING'] = reqUri[1]
+            else:
+                environ['QUERY_STRING'] = ''
 
     def error(self, request):
         """
